]> Shamusworld >> Repos - rmac/blobdiff - token.h
Change extension to .prg when invoked with -p.
[rmac] / token.h
diff --git a/token.h b/token.h
index c7dc4b194cceffc74eecbb50a4bdf02f5f727e84..3d3ea22c017b4f1a5c7fc144c1e83818a6d5ed52 100644 (file)
--- a/token.h
+++ b/token.h
@@ -3,7 +3,7 @@
 // TOKEN.H - Token Handling
 // Copyright (C) 199x Landon Dyer, 2011 Reboot and Friends
 // RMAC derived from MADMAC v1.07 Written by Landon Dyer, 1986
-// Source Utilised with the Kind Permission of Landon Dyer
+// Source utilised with the kind permission of Landon Dyer
 //
 
 #ifndef __TOKEN_H__
@@ -111,8 +111,8 @@ IFILE {
 
 #define TOKENSTREAM struct _tokenstream
 TOKENSTREAM {
-       TOKEN token[10];                // 10 ought to be enough for anybody
-       char * string[10];              // same for attached strings
+       TOKEN token[32];                // 32 ought to be enough for anybody (including XiA!)
+       char * string[32];              // same for attached strings
 };
 
 // Information about a macro invocation